==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/PolarScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarBase } from "./PolarBase";
import { markType } from "igniteui-angular-core";
import { PolarBaseView } from "./PolarBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var PolarScatterSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarScatterSeries, _super);
    function PolarScatterSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarScatterSeries.$;
        return _this;
    }
    PolarScatterSeries.prototype.get_dx = function () {
        return true;
    };
    PolarScatterSeries.prototype.cg = function () {
        return new PolarScatterSeriesView(this);
    };
    PolarScatterSeries.prototype.o0 = function (a) {
        _super.prototype.o0.call(this, a);
        this.y8 = a;
    };
    PolarScatterSeries.prototype.iq = function () {
        return 0.7;
    };
    PolarScatterSeries.prototype.t4 = function () {
        if (this.t3 == 0) {
            return 2;
        }
        return _super.prototype.t4.call(this);
    };
    PolarScatterSeries.$t = markType(PolarScatterSeries, 'PolarScatterSeries', PolarBase.$);
    return PolarScatterSeries;
}(PolarBase));
export { PolarScatterSeries };
/**
 * @hidden
 */
var PolarScatterSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarScatterSeriesView, _super);
    function PolarScatterSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c6 = null;
        _this.c6 = a;
        return _this;
    }
    PolarScatterSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c6.ua = Defaults.e;
        }
    };
    PolarScatterSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.s6 = a;
        this.e.ir = 3;
        this.e.is = 2;
        this.e.it = 2;
        this.e.gj = false;
    };
    PolarScatterSeriesView.$t = markType(PolarScatterSeriesView, 'PolarScatterSeriesView', PolarBaseView.$);
    return PolarScatterSeriesView;
}(PolarBaseView));
export { PolarScatterSeriesView };

==> igniteui-angular-charts-18.2.0-beta.0.tgz: package/esm5/lib/PolarScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarBase } from "./PolarBase";
import { markType } from "igniteui-angular-core";
import { PolarBaseView } from "./PolarBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var PolarScatterSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarScatterSeries, _super);
    function PolarScatterSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarScatterSeries.$;
        return _this;
    }
    PolarScatterSeries.prototype.bj = function () {
        return new PolarScatterSeries();
    };
    PolarScatterSeries.prototype.get_ei = function () {
        return true;
    };
    PolarScatterSeries.prototype.cs = function () {
        return new PolarScatterSeriesView(this);
    };
    PolarScatterSeries.prototype.qz = function (a) {
        _super.prototype.qz.call(this, a);
        this.ace = a;
    };
    PolarScatterSeries.prototype.jl = function () {
        return 0.7;
    };
    PolarScatterSeries.prototype.wz = function () {
        if (this.wy == 0) {
            return 2;
        }
        return _super.prototype.wz.call(this);
    };
    PolarScatterSeries.$t = markType(PolarScatterSeries, 'PolarScatterSeries', PolarBase.$);
    return PolarScatterSeries;
}(PolarBase));
export { PolarScatterSeries };
/**
 * @hidden
 */
var PolarScatterSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarScatterSeriesView, _super);
    function PolarScatterSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c8 = null;
        _this.c8 = a;
        return _this;
    }
    PolarScatterSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c8.w8 = Defaults.e;
        }
    };
    PolarScatterSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.vz = a;
        this.e.jm = 3;
        this.e.jn = 2;
        this.e.jo = 2;
        this.e.hc = false;
    };
    PolarScatterSeriesView.$t = markType(PolarScatterSeriesView, 'PolarScatterSeriesView', PolarBaseView.$);
    return PolarScatterSeriesView;
}(PolarBaseView));
export { PolarScatterSeriesView };
